@@ -311,7 +311,10 @@ class FormaPagamentoRetornoResource(PagamentoConfiguracaoBaseResource):
         self.conta_id = conta_id
         try:
             self.dados["conta_id"] = conta_id
-            registro = RegistrarPagamento(self.dados, self.pagamento_configuracao, tipo)
+            if conta_id:
+                registro = RegistrarPagamento(self.dados, tipo=tipo, configuracao_pagamento=self.pagamento_configuracao)
+            else:
+                registro = RegistrarPagamento(self.dados, tipo=tipo, pagamento_id=pagamento_id)
             resultado = registro.processar()
             if "redirect" in resultado:
                 return redirect(resultado["redirect"], code=301)
