@@ -17,8 +17,10 @@ class Plugavel(object):
             return modulo
         except KeyError:
             raise MeioDePagamentoNaoDefinido(u"O meio de pagamento '{}' não foi encontrada nas configurações. Você esqueceu de inclui-la em pagador.settings.LIBS_MEIOS_DE_PAGAMENTO?".format(self.meio_pagamento))
-        except ImportError:
-            raise MeioDePagamentoNaoEncontrado(u"Não foi encontrado o modulo '{}.{}' para o meio de pagamento '{}' no ambiente.".format(import_meio_pagamento, tipo, self.meio_pagamento))
+        except ImportError, ex:
+            if tipo in unicode(ex):
+                raise MeioDePagamentoNaoEncontrado(u"Não foi encontrado o modulo '{}.{}' para o meio de pagamento '{}' no ambiente.".format(import_meio_pagamento, tipo, self.meio_pagamento))
+            raise
 
 
 class PluginNaoEncontrado(Exception):
