@@ -38,6 +38,10 @@ class RegistroBase(object):
     def grava_identificador(self):
         return False
 
+    @property
+    def valores_de_pagamento(self):
+        return None
+
     @property
     def situacao_do_pedido(self):
         raise NotImplementedError
@@ -114,7 +118,7 @@ class RegistrarPagamento(Plugavel):
         if self.registrador.obter_dados_do_gateway:
             self.registrador.dados.update(self.obtem_dados_do_gateway())
         if self.registrador.grava_identificador:
-            self.grava_identificacao_de_pagamento()
+            self.grava_dados_de_pagamento(valores=self.registrador.valores_de_pagamento)
         if self.registrador.alterar_situacao:
             if self.achou_registro:
                 resultado["pedido_venda_situacao_id"] = self.registrador.situacao_do_pedido
@@ -133,22 +137,26 @@ class RegistrarPagamento(Plugavel):
         resultado["resultado"] = "OK"
         return resultado
 
-    def get(self, segunda_tentativa=False):
+    def post(self, segunda_tentativa=False):
         conexao = Conexao(self.meio_pagamento, self.configuracao_pagamento, self.registrador, TipoConexao.retorno, self.processar_resposta)
-        return conexao.get(segunda_tentativa)
+        return conexao.post(segunda_tentativa)
 
     def obtem_dados_do_gateway(self):
-        resultado = self.get()
+        resultado = self.post()
         if resultado.get("reenviar", False):
             resultado = self.get(segunda_tentativa=True)
         if resultado["status"] == 200:
             return resultado["content"]
         return {}
 
-    def grava_identificacao_de_pagamento(self):
+    def grava_dados_de_pagamento(self, valores=None):
         if not self.conta_id or not self.registrador.pedido_numero or not self.configuracao_pagamento:
             return None
         pedido = Pedido.objects.get(conta_id=self.conta_id, numero=self.registrador.pedido_numero)
         pedido_pagamento = PedidoPagamento.objects.get(pedido=pedido, pagamento=self.configuracao_pagamento.forma_pagamento)
-        pedido_pagamento.identificador_id = self.registrador.identificador_id
+        if valores:
+            for chave in valores.keys():
+                setattr(pedido_pagamento, chave, valores[chave])
+        else:
+            pedido_pagamento.identificador_id = self.registrador.identificador_id
         pedido_pagamento.save()
